/* $Workfile: OtxBurstD.h $   $Revision: 1 $    $Modtime: 2/24/03 2:56p $  */

#ifndef OTX_BURST_DEF_H
#define OTX_BURST_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxBurstD

  Copyright (C) 1998, 1999, 2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBurstD | Constants, Macros, and Types for the DMA Burst Device Management Functions

  @contents2
  OtxBurstD.h |

  @index enum struct type | OtxBurstD

  @contents2
  OTX DMA Burst Device Management Macros, Constants, and Types |

  @head3 OtxBurstXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxBurstD

*******************************************************************************/

#include "OtxType.h"    // OTX specific type definitions

#include "OtxErr.h"

#ifdef __cplusplus
extern "C" {
#endif


/*---------------------------------------------------------------------------*\
  @enum 
    DSP Device Attributes
\*---------------------------------------------------------------------------*/
enum OtxBurstDeviceAttributesE {
  OTX_ATTR_BURST_DMA_BUFFER         = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Address of User DMA Buffer.
                                                         // If the User DMA buffer is NULL, double buffering will take place (the driver will allocate
                                                         // and use its own internal DMA buffer.

  OTX_ATTR_BURST_DMA_BUFFER_SIZE    = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Size of User DMA Buffer.
                                                         // If the User DMA buffer size is 0, double buffering will take place (the driver will allocate
                                                         // and use its own internal DMA buffer.

  OTX_ATTR_BURST_DMA_FRAME_MASK     = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Frame mask.
                                                         // Defines the number of frames that will cause a burst device data transfer.

  OTX_ATTR_BURST_END                = OTX_ATTR_END + 4   // and use its own internal DMA buffer.
};

typedef enum OtxBurstDeviceAttributesE OtxBurstDeviceAttributesE;

/*---------------------------------------------------------------------------*\
  @enum
    DSP Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxBurstResultCodesE {
  OTX_BURST_RES_DATA_TOO_LARGE               = OTX_RES_END +  0 ,  // @emem Data too large for the supplied buffer. Supply a larger buffer.
  OTX_BURST_RES_INVALID_CHANNEL              = OTX_RES_END +  1 ,  // @emem Invalid channel
  OTX_BURST_RES_COMM_FAILURE                 = OTX_RES_END +  2 ,  // @emem Communication failure with the DSP
  OTX_BURST_RES_NO_KERNEL_RESPONSE           = OTX_RES_END +  3 ,  // @emem No response from DSP Kernel
  OTX_BURST_RES_NO_FREE_LOGICAL_DEVICE       = OTX_RES_END +  4 ,  // @emem No free logical device

  OTX_BURST_RES_END                          = OTX_RES_END +  1
};

typedef enum OtxBurstResultCodesE OtxBurstResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    DSP Event Codes
\*---------------------------------------------------------------------------*/
enum OtxBurstEventCodesE {
  // OtxSpm1 Specific Event Codes
  OTX_BURST_EC_RX_OVERFLOW                 = 0x00, // @emem OtxSpm1 Receive overflow
  OTX_BURST_EC_INTERNAL_ERROR              = 0x01, // @emem OtxSpm1 Undefined Internal error
  OTX_BURST_EC_UNKNOWN_NOTIFY_CODE         = 0x02, // @emem OtxSpm1 Error. Unknown notify code for System Notify Event Handle.

  // Generic DSP Module Event Codes
  OTX_BURST_EC_INVALID_NOTIFY_EVENT_HANDLE = 0x03, // @emem Invalid Notify Event Handle. Could not find a matching logical device for this handle.
  OTX_BURST_EC_NOTIFY_EVENT_OVERFLOW       = 0x04, // @emem Event frequency too high. Driver cannot handle all these events. 
  OTX_BURST_EC_AUTO_DISABLED               = 0x05, // @emem Fatal error has occurred. The device is automatically disabled.
  OTX_BURST_EC_NOTIFY_EVENT_FREQ_HIGH      = 0x06, // @emem Event frequency from the DSP is seriously high. Fatal errors are imminent.
//OTX_BURST_EC_DEBUG_INFO                  = 0x07, // @emem Internal use. For driver debugging.

  OTX_BURST_END_OF_EVENT_CODES          
};
typedef enum OtxBurstEventCodesE OtxBurstEventCodesE;


/*---------------------------------------------------------------------------*\
  @enum
    User Application Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxUserApplicationResultCodesE {
  OTX_USER_APPLICATION_RES_DATA_TRUNCATED  = OTX_RES_END +  0 ,  // @emem DSP User application has transferred a data buffer that is too large. Data is truncated.        
  OTX_USER_APPLICATION_RES_END             = OTX_RES_END +  1
};

typedef enum OtxUserApplicationResultCodesE OtxUserApplicationResultCodesE;


/*---------------------------------------------------------------------------*\
  @enum
    DSP User Application Logical Device Event Codes
\*---------------------------------------------------------------------------*/
enum OtxUserApplicationEventCodesE {
  OTX_USER_APPLICATION_EC_READ_DATA                = 0x00, // @emem DSP User Application Notify Data is available
  OTX_USER_APPLICATION_EC_READ_DATA_OVERRUN        = 0x01, // @emem DSP User Application Notify Data Fifo Overrun. User application is too slow extracting data from the driver

  OTX_USER_APPLICATION_END_OF_EVENT_CODES          
};
typedef enum OtxUserApplicationEventCodesE OtxUserApplicationEventCodesE;


#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998, 1999, 2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif    // OTX_BURST_DEF_H
